tests.test_readwrite module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- tests »
- tests package »

# tests.test_readwrite module

## tests.test_readwrite

Tests reading and writing of graph.

class `tests.test_readwrite.` `TestRewriter`

  Bases: `object`

  Test rewriting of a graph.

  `test_inverses`()

    Verify that destringize inverts stringize.

class `tests.test_readwrite.` `TestStringUtils`

  Bases: `object`

  Test utilities that work over networkx graphs.

  `test_as_string`()

    Verify non-empty string.

  `test_from_string`()

    Verify succesful reading of empty graph.

  `test_inverses`()

    Test that writing the string and then reading it yields identical graph.

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- tests »
- tests package »